<?php
/**
 * A custom autoloader for the locrMAPS WordPress plugin.
 *
 * @link https://www.php-fig.org/psr/psr-4/
 * @package Locr\WordPress\Plugin\LocrMaps
 */

declare(strict_types=1);

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

spl_autoload_register(
	function ( string $class_name ) {
		// project-specific namespace prefix.
		$prefix = 'Locr\\WordPress\\Plugin\\LocrMaps\\';

		// base directory for the namespace prefix.
		$base_dir = __DIR__ . DIRECTORY_SEPARATOR . 'includes';

		// does the class use the namespace prefix?
		$len = strlen( $prefix );
		if ( strncmp( $prefix, $class_name, $len ) !== 0 ) {
			// no, move to the next registered autoloader.
			return;
		}

		// get the relative class name.
		$relative_class             = substr( $class_name, $len );
		$relative_filename          = strtolower( str_replace( '\\', '/', $relative_class ) . '.php' );
		$splitted_relative_filename = explode( '/', $relative_filename );
		if ( count( $splitted_relative_filename ) > 1 ) {
			$last_index                                = count( $splitted_relative_filename ) - 1;
			$splitted_relative_filename[ $last_index ] = 'class-' . $splitted_relative_filename[ $last_index ];
			$relative_filename                         = implode( '/', $splitted_relative_filename );
		} else {
			$relative_filename = 'class-' . $relative_filename;
		}

		// replace the namespace prefix with the base directory, replace namespace
		// separators with directory separators in the relative class name, append
		// with .php.
		$file = $base_dir . DIRECTORY_SEPARATOR . $relative_filename;

		// if the file exists, require it.
		if ( file_exists( $file ) ) {
			require_once $file;
		}
	}
);
