<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\CountryAndLanguage;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the ISO 3166-1 numeric code.
 *
 * @property-read int $value The raw code.
 */
final class ISO3166Numeric {
	/**
	 * The code value of the country.
	 *
	 * @var int
	 */
	private readonly int $value;

	/**
	 * The constructor.
	 *
	 * @param mixed $value The ISO3166-1:numeric code of the country.
	 * @throws \InvalidArgumentException If the id is not numeric or less than 1.
	 */
	public function __construct( mixed $value ) {
		if ( is_string( $value ) && empty( $value ) ) {
			$value = 0;
		}
		if ( ! is_int( $value ) ) {
			throw new \InvalidArgumentException( 'The value for ISO3166-1:numeric must be an integer.' );
		}
		if ( $value < 0 ) {
			throw new \InvalidArgumentException( 'The value for ISO3166-1:numeric must be greater than 0.' );
		}
		if ( $value > 999 ) {
			throw new \InvalidArgumentException( 'The value for ISO3166-1:numeric must be less than 999.' );
		}

		$this->value = $value;
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'value' => $this->value,
			default => throw new \InvalidArgumentException( 'The property "' . esc_html( $name ) . '" does not exist.' ),
		};
	}
}
