<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\OnlineMap\Location;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the location id.
 *
 * @property-read int $value The raw value.
 */
final class Id {
	/**
	 * The id value of the location.
	 *
	 * @var int
	 */
	private readonly int $value;

	/**
	 * The constructor.
	 *
	 * @param mixed $value The id of the location.
	 * @throws \InvalidArgumentException If the id is not numeric or less than 1.
	 */
	public function __construct( mixed $value ) {
		if ( ! is_int( $value ) && ! is_string( $value ) ) {
			throw new \InvalidArgumentException( 'The id must be an integer or a string.' );
		}
		if ( ! is_numeric( $value ) ) {
			throw new \InvalidArgumentException( 'The id must be numeric.' );
		}

		$value = intval( $value );
		if ( $value < 1 ) {
			throw new \InvalidArgumentException( 'The id must be greater than 0.' );
		}

		$this->value = $value;
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'value' => $this->value,
			default => throw new \InvalidArgumentException( 'The property "' . esc_html( $name ) . '" does not exist.' ),
		};
	}
}
